@@ -22,6 +22,8 @@ from .eo_types import (
     NoDockerContainerException,
     InvalidDockerContainerException,
     UnauthorizedUserException,
+    DockerRegistryException,
+    UnknownDockerException,
 )
 
 _logger = logging.getLogger(__name__)
@@ -112,7 +114,12 @@ def login(test):
     try:
         embedops_authorization.fetch_registry_token()
         embedops_authorization.login_to_registry()
-    except (UnauthorizedUserException, LoginFailureException) as exc:
+    except (
+        UnauthorizedUserException,
+        LoginFailureException,
+        DockerRegistryException,
+        UnknownDockerException,
+    ) as exc:
         _echo_error_and_fix(
             exc
         )  # TODO: add context to these so we know WHICH login failed
